netapp_ontap.models.s3_bucket_lifecycle_management_rules API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.s3_bucket_lifecycle_management_rules`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class S3BucketLifecycleManagementRulesSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the S3BucketLifecycleManagementRules object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `abort_incomplete_multipart_upload: S3BucketLifecycleAbortIncompleteMultipartUpload GET POST PATCH`

    Information about the abort-incomplete-multipart-upload lifecycle management action.

  `bucket_name: str GET POST`

    Specifies the name of the bucket. Bucket name is a string that can only contain the following combination of ASCII-range alphanumeric characters 0-9, a-z, ".", and "-".

    Example: bucket1

  `enabled: bool GET POST PATCH`

    Specifies whether or not the associated rule is enabled.

  `expiration: S3BucketLifecycleExpiration GET POST PATCH`

    Information about the expiration lifecycle management action.

  `links: SelfLink GET`

    The links field of the s3_bucket_lifecycle_management_rules.

  `name: str GET POST`

    Bucket lifecycle management rule identifier. The length of the name can range from 0 to 256 characters.

  `non_current_version_expiration: S3BucketLifecycleNonCurrentVersionExpiration GET POST PATCH`

    Information about the non-current-version-expiration lifecycle management action.

  `object_filter: S3BucketLifecycleObjectFilter GET POST`

    Information about the lifecycle management rule of a bucket.

  `svm: Svm GET`

    The svm field of the s3_bucket_lifecycle_management_rules.

  `uuid: str GET`

    Specifies the unique identifier of the bucket.

    Example: 414b29a1-3b26-11e9-bd58-0050568ea055